pub struct NormalizedTransaction {
pub ins: Option<Vec<UtxoId>>,
pub refs: BTreeSet<UtxoId>,
pub outs: Vec<NormalizedCharms>,
}Expand description
Normalized representation of a Charms transaction.
Fields
ins: Option<Vec<UtxoId>>(Optional) input UTXO list. Is None when serialized in the transaction: the transaction already lists all inputs. Must be in the order of the transaction inputs.
refs: BTreeSet<UtxoId>Reference UTXO list. May be empty.
outs: Vec<NormalizedCharms>Output charms. Must be in the order of the transaction outputs. When proving correctness of a spell, we can’t know the transaction ID yet. We only know the index of each output charm. Must be in the order of the hosting transaction’s outputs. Must not be larger than the number of outputs in the hosting transaction.
Implementations
Sourceimpl NormalizedTransaction
impl NormalizedTransaction
Sourcepub fn prev_txids(&self) -> Option<BTreeSet<&TxId>>
pub fn prev_txids(&self) -> Option<BTreeSet<&TxId>>
Return a sorted set of transaction IDs of the inputs.